tags: skip ./ in filenames
PATCH 8/13 tags: skip ./ in filenames
From: Alexey Dobriyan <[email protected]>
This drives size of tags file from 68.9 MB down to 67.7 MB.
Signed-off-by Alexey Dobriyan <[email protected]>
Cc Sam Ravnborg <[email protected]>
Signed-off-by Andrew Morton <[email protected]>
---
Makefile | 2 +- 1 file changed, 1 insertion(+), 1 deletion(-)
Makefile renamed from Makefile~tags-skip-in-filenames +1 -1
@@ -1456,7 +1456,7 @@ define find-sources -name $1 -print; \ find $(__srctree) $(RCS_FIND_IGNORE) \ \( -name include -o -name arch -o -name '.tmp_*' \) -prune -o \ - -name $1 -print; \ + -name $1 -print | sed -e 's#^./##'; \ ) endef
_